.. currentmodule:: ldgm
.. ldgm documentation master file, created by Wilder Wohns

Welcome to ldgm's documentation
==================================

``ldgm`` is a software package that enables extremely sparse and highly accurate modeling of linkage disequilibrium (LD).


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   installation
   tutorial
   python-api
   matlab-api



Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
